ConfigurableMultiFileLoader

Struct ConfigurableMultiFileLoader 

pub struct ConfigurableMultiFileLoader { /* private fields */ }
Configurable multi-file image loader

This loader can be configured to work with different multifile sensor formats by providing appropriate configuration parameters for file patterns, band schemes, and naming conventions.

Implementations

Source

impl ConfigurableMultiFileLoader

pub fn new(config: MultiFileLoaderConfig) -> Result<Self>

Create a new configurable multifile loader

pub fn from_config(config: &HashMap<String, String>) -> Result<Self>

Create a loader from a configuration HashMap