pub struct ConfigurableMultiFileLoader { /* private fields */ }Expand description
Configurable multi-file image loader
This loader can be configured to work with different multifile sensor formats by providing appropriate configuration parameters for file patterns, band schemes, and naming conventions.
Implementations
Sourceimpl ConfigurableMultiFileLoader
impl ConfigurableMultiFileLoader
Sourcepub fn new(config: MultiFileLoaderConfig) -> Result<Self>
pub fn new(config: MultiFileLoaderConfig) -> Result<Self>
Create a new configurable multifile loader