pub struct SingleFileLoader { /* private fields */ }Expand description
Image loader for single-file captures (RGB images, etc.)
This loader handles standard image files where each capture consists of a single file containing all bands. Common for RGB cameras and some single-band or composite multispectral formats.
Implementations
Sourceimpl SingleFileLoader
impl SingleFileLoader
Sourcepub fn new(
extensions: Vec<String>,
band_count: usize,
bit_depth: u8,
) -> Result<Self>
pub fn new( extensions: Vec<String>, band_count: usize, bit_depth: u8, ) -> Result<Self>
Create a new single-file loader
Arguments
extensions- Supported file extensions (without dots, e.g., [“jpg”, “png”])band_count- Expected number of bands/channels in each imagebit_depth- Bit depth of the sensor (8, 16, or 32)
Sourcepub fn tiff_16bit(band_count: usize) -> Result<Self>
pub fn tiff_16bit(band_count: usize) -> Result<Self>
Create a loader for 16-bit TIFF images